pub struct SignerMessagePart {
pub party_id: PartyId,
pub verification_key_for_concatenation: HexEncodedVerificationKeyForConcatenation,
pub verification_key_signature_for_concatenation: Option<HexEncodedVerificationKeySignatureForConcatenation>,
pub operational_certificate: Option<HexEncodedOpCert>,
pub kes_evolutions: Option<KesEvolutions>,
pub verification_key_for_snark: Option<HexEncodedVerificationKeyForSnark>,
pub verification_key_signature_for_snark: Option<HexEncodedVerificationKeySignatureForSnark>,
}Expand description
Signer Message
Fields
party_id: PartyIdThe unique identifier of the signer
Used only for testing when SPO pool id is not certified
verification_key_for_concatenation: HexEncodedVerificationKeyForConcatenationThe verification key for the Concatenation proof system
verification_key_signature_for_concatenation: Option<HexEncodedVerificationKeySignatureForConcatenation>The encoded signer ‘Mithril verification key’ signature (signed by the Cardano node KES secret key).
None is used only for testing when SPO pool id is not certified
operational_certificate: Option<HexEncodedOpCert>The encoded operational certificate of stake pool operator attached to the signer node.
None is used only for testing when SPO pool id is not certified
kes_evolutions: Option<KesEvolutions>The number of evolutions of the KES key since the start KES period of the operational certificate at the time of signature.
verification_key_for_snark: Option<HexEncodedVerificationKeyForSnark>The verification key for the SNARK proof system (hex encoded)
verification_key_signature_for_snark: Option<HexEncodedVerificationKeySignatureForSnark>The KES signature over the verification key for SNARK (hex encoded)
Implementations
Sourceimpl SignerMessagePart
impl SignerMessagePart
Sourcepub fn try_into_signers(messages: Vec<Self>) -> StdResult<Vec<Signer>>
pub fn try_into_signers(messages: Vec<Self>) -> StdResult<Vec<Signer>>
Convert a set of signer message parts into a set of signers
Sourcepub fn from_signers(signers: Vec<Signer>) -> Vec<Self>
pub fn from_signers(signers: Vec<Signer>) -> Vec<Self>
Convert a set of signers into message parts
Sourcepub fn without_snark_fields(self) -> Self
pub fn without_snark_fields(self) -> Self
Remove SNARK-related fields for backward compatibility with older clients.
This is needed during the Pythagoras era to avoid deserialization failures in older signers/aggregators that don’t know about the SNARK fields.
Sourcepub fn strip_snark_fields(signers: Vec<Self>) -> Vec<Self>
pub fn strip_snark_fields(signers: Vec<Self>) -> Vec<Self>
Remove SNARK-related fields from a list of signer message parts for backward compatibility.